<?php

namespace Drupal\search_api_synonym\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for deleting all Synonym entities.
 *
 * @ingroup search_api_synonym
 */
class SynonymDeleteAllForm extends FormBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The messenger service.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * Constructs a new SynonymDeleteAllForm.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity manager.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger service.
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager, MessengerInterface $messenger) {
    $this->entityTypeManager = $entityTypeManager;
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delete_all_synonyms_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Add a confirmation message.
    $form['confirmation'] = [
      '#markup' => $this->t('Are you sure you want to delete all synonyms? This action cannot be undone.'),
      '#prefix' => '<div>',
      '#suffix' => '</div>',
    ];

    // Confirmation button to delete entities.
    $form['delete_all'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete All Synonyms'),
      '#button_type' => 'danger',
    ];

    // Cancel button to go back.
    $form['cancel'] = [
      '#type' => 'link',
      '#title' => $this->t('Cancel'),
      '#url' => Url::fromRoute('entity.search_api_synonym.collection'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $storage = $this->entityTypeManager->getStorage('search_api_synonym');
    $synonyms = $storage->loadMultiple();

    if (!empty($synonyms)) {
      $storage->delete($synonyms);
    }

    // Add a success message and redirect.
    $this->messenger->addMessage($this->t('All Synonyms have been deleted.'));
    $form_state->setRedirectUrl(Url::fromRoute('entity.search_api_synonym.collection'));
  }

}
